@@ -2,24 +2,17 @@
 #
 # Author: Thamme Gowda [tg (at) isi (dot) edu] 
 # Created: 6/13/20
-from pyspark.sql import SparkSession
-import logging as log
-import os
-from typing import List, Dict, Tuple
-from pathlib import Path
 import json
+import logging as log
+from pathlib import Path
+from typing import List, Dict, Tuple
+
+from nlcodec import spark as spark_util
+from nlcodec import __version__,  __epilog__
 
-SPARK_DRIVER_MEM = os.environ.get("SPARK_DRIVER_MEM", "4g")
-SPARK_MASTER = os.environ.get("SPARK_MASTER", "local[*]")
-SPARK_APP_NAME = os.environ.get("SPARK_APP", "NLCoDec")
 log.basicConfig(level=log.INFO)
 
-def get_spark(app_name=SPARK_APP_NAME, master=SPARK_MASTER, driver_mem=SPARK_DRIVER_MEM):
-    return SparkSession.builder \
-        .appName(app_name) \
-        .master(master)\
-        .config("spark.driver.memory", driver_mem) \
-        .getOrCreate()
+
 
 def word_counts(paths: List[Path], dedup=True, spark=None) \
         -> Tuple[Dict[str, int], Dict[str, int], int]:
@@ -32,7 +25,7 @@ def word_counts(paths: List[Path], dedup=True, spark=None) \
     :return: word_freqs, char_freqs, line_count
     """
     own_spark = not spark
-    spark = spark or get_spark()
+    spark = spark or spark_util.get_session()
     log.info(f"Spark Session is up; you may check web UI")
     try:
         for p in paths:
@@ -50,18 +43,18 @@ def word_counts(paths: List[Path], dedup=True, spark=None) \
         # Tokenize
         # also include a special token, one per line to count lines
         # expand words as sep records
-        word_freqs = df.rdd.flatMap(lambda row: [ SENT_TAG ] + row.value.strip().split())\
-            .map(lambda word: (word, 1))\
-            .reduceByKey(lambda v1,  v2: v1 + v2)\
+        word_freqs = df.rdd.flatMap(lambda row: [SENT_TAG] + row.value.strip().split()) \
+            .map(lambda word: (word, 1)) \
+            .reduceByKey(lambda v1, v2: v1 + v2) \
             .collectAsMap()
         line_count = word_freqs.pop(SENT_TAG)
-        #word_freqs = list(sorted(word_freqs.items(), key=lambda x: x[1], reverse=True))
+        # word_freqs = list(sorted(word_freqs.items(), key=lambda x: x[1], reverse=True))
 
         # char freqs
         char_freqs = (spark.sparkContext.parallelize(word_freqs.items())
-             .flatMap(lambda r: [(ch, r[1]) for ch in r[0]])
-             .reduceByKey(lambda a, b: a + b)
-            .collectAsMap())
+                      .flatMap(lambda r: [(ch, r[1]) for ch in r[0]])
+                      .reduceByKey(lambda a, b: a + b)
+                      .collectAsMap())
 
         return word_freqs, char_freqs, line_count
 
@@ -71,6 +64,7 @@ def word_counts(paths: List[Path], dedup=True, spark=None) \
             log.info(f"Stopping spark session")
             spark.stop()
 
+
 def write_stats(stats: Dict[str, int], out, **meta):
     stats = sorted(stats.items(), key=lambda x: x[1], reverse=True)
     stats = list(stats)
@@ -85,6 +79,7 @@ def write_stats(stats: Dict[str, int], out, **meta):
         out.write(f'{term}\t{freq}\n')
     log.info(f"Wrote {out}")
 
+
 def main(args=None):
     args = args or parse_args()
     word_freqs, char_freqs, line_count = word_counts(args.inp, dedup=args.dedup)
@@ -96,7 +91,9 @@ def main(args=None):
 
 def parse_args():
     import argparse
-    p = argparse.ArgumentParser(formatter_class=argparse.ArgumentDefaultsHelpFormatter)
+    p = argparse.ArgumentParser(formatter_class=argparse.ArgumentDefaultsHelpFormatter,
+                                epilog=__epilog__)
+    p.add_argument('-v', '--version', action='version', version=f'%(prog)s {__version__}')
     p.add_argument('-i', '--inp', type=Path, nargs='+',
                    help='Input file paths')
     p.add_argument('-wf', '--word_freqs', type=argparse.FileType('w'), default=None,
@@ -110,7 +107,7 @@ def parse_args():
                    help='Do not deduplicate. ')
     args = p.parse_args()
     assert args.word_freqs or args.char_freqs, \
-            'At least one of --word_freqs --char_freqs paths be given to write the stats'
+        'At least one of --word_freqs --char_freqs paths be given to write the stats'
     return args
 
 
